@@ -283,8 +283,10 @@ c                  k0s
              endif
           else
              write(msg,*) ' ptcl code=',kidn,' not acceptable in ',
-     *                  ' cfritiof '
-             call cerrorMsg(msg, 0)
+     *                  ' cfritiof; event neglectd '
+             call cerrorMsg(msg, 1)
+             np = 0
+             return  !  exit
           endif
 #ifdef USE_STRANGEFLAG
 c           skip particles of undefined code; 
@@ -462,7 +464,7 @@ c
        real*4 elab, plab, anuc, znuc
        integer kidn, icg, iproty, itta, l, kk, ktmp, ctmp, pap
        real*8 et, u
-       character*70  msg
+       character*100  msg
 c
 c
          elab=pj.fm.p(4)
@@ -503,8 +505,10 @@ c        --- fix projectile --------------
              endif
           else
              write(msg,*) ' ptcl code=',kidn,' not acceptable in ',
-     *        ' cnucrin '
-             call cerrorMsg(msg, 0)
+     *        ' cnucrin; envet neglected '
+             call cerrorMsg(msg, 1)
+             np = 0
+             return  ! ***********
           endif
 c                generate ptcls
           if(ia .gt. 1) then
@@ -612,9 +616,11 @@ c                    mu-
                   ctmp=-1
                   pap=regptcl
               else
-                  write(msg,*) ' ptcl code=',kk,' from nucrin',
+                 write(msg,*) ' ptcl code=',kk,' from nucrin',
      *            ' not acceptable in cnucrin'
-                  call cerrorMsg(msg, 0)
+                  call cerrorMsg(msg, 1)
+                  call cerrorMsg(' it is neglected' ,1)
+                  goto 10    ! *************
               endif
               np=np+1
               call cmkptc(ktmp, pap, ctmp, a(np))
@@ -629,6 +635,7 @@ c                  sometimes nucrin give unbalanced energy mom. at low E
      *        - a(np).fm.p(4)**2)/a(np).fm.p(4)  .gt. .005) then
                  call cadjm(a(np), a(np))
               endif
+ 10           continue
            enddo
         end
         subroutine chadrin(iproty, plab, elab, itta)
