@@ -1,6 +1,13 @@
+#include  "Zmaxdef.h"
 #include  "Ztrack.h"
           integer Max_stack_size
-          parameter (Max_stack_size =15000)
+          parameter (
+#ifdef MAX_STACK
+     *    Max_stack_size = MAX_STACK
+#else
+     *    Max_stack_size =15000
+#endif
+     *    )
           integer Stack_pos
           record /track/ Stack(Max_stack_size)
           common /Zstack/ Stack, Stack_pos
