@@ -15,7 +15,7 @@ c
 
       character*70 msg
       character*16 temp
-      integer jold
+      integer jold, icon
       real*8 s1
 
       if(Cont) then
@@ -24,6 +24,21 @@ c           restore status at the end of previous run
       elseif(Job .eq. 'flesh' ) then
          call cgetSkelFile 
          Job = 'flesh'    ! Job='flesh' is kept as now
+      elseif(Job .eq. 'skeleton') then
+c            to be safe, parameters are written in a file first and read
+c            again ; this will avoid the possible difference of internal
+c            parameter values read from original param and SkeletonParam
+c
+         call copenfw(TempDev, SkeletonFile, icon)
+         if(icon .ne. 0) then
+            call cerrorMsg(SkeletonFile, 1)
+            call cerrorMsg('File shown above cannot be opened',0)
+         endif
+         call cwriteParam(TempDev, 1)
+         close(TempDev)
+         call copenf(TempDev, SkeletonFile, icon)
+         call creadParam(TempDev)
+         close(TempDev)
       endif
 
 c        reset parameters.
@@ -31,8 +46,10 @@ c        reset parameters.
          BorderHeightH = HeightOfInj
       endif
 
-      if(DestEventNo(2) .le. 0) then
+      if(DestEventNo(2) .eq. 0) then
          DestEventNo(2) = DestEventNo(1)
+      elseif(DestEventNo(1) .lt. 0) then
+         DestEventNo(2) = -abs(DestEventNo(2))
       endif
 
 c         to lower case letters.
@@ -81,8 +98,20 @@ c       init for muon interaction routines; specific for Air.
 
       call ciniSPrimAng    !  this is in csPrimaAgn.f in Tracking dir.
       call ciniTracking0  !  init for  tracking for all events
+
 c        check job
       call cwhatJob
+
+c           init for knockon process; Knockon is not used now.
+      if(KnockOnRatio .lt. 1.d0) then
+c                 this must come after cwhatJob, since KEminObs2 must
+c           be fixed.  For skeleton-flesh job, KnockOnRatio should be
+c           small enough so that KEminObs2*KnockOnRatio < KEminObs at
+c           flesh time  
+         call cdedxEleci(KEminObs2*KnockOnRatio, Knockon)
+      else
+         call cdedxEleci(RecoilKineMinE, Knockon)
+      endif
 c         user hook
       call chookBgRun
       end
