@@ -134,7 +134,7 @@ c              int(5 to g) of p(x)dx~ (2x)**p/xdx
       call rndc(u)
       if(u  .lt. int1/(int1+int2)) then
 c            use rejection.
-c           integral of 1/sqrt(2(x-1)) from 1 go xm
+c           integral of 1/sqrt(2(x-1)) from 1 to xm
        int1 = sqrt(2.0*(xm-1.0))
 c           integral of (2x)**p/x from (1 to xm)
        int2 = 2.0**p/p *(xm**p-1.0)
@@ -150,6 +150,7 @@ c            use dx(2x)**p/x
              call rndc(u)
              x =( p*int2*u/2.0**p+ 1.)**(1./p)
           endif
+          if(x .eq. 1.0) goto 10
           call rndc(u)
           tf = 1./(x-sqrt(x*x-1.0))**p/sqrt(x*x-1.0)
           rf = (2.0*x)**p/x + 1.0/sqrt(2*(x-1.0))
