@@ -15,7 +15,7 @@ c
 #include  "Zobsp.h"
 #include  "Zobsv.h"
 #include  "Zearth.h"
-
+#include  "Zincidentp.h"
 c
        integer i, icon
        logical error
@@ -42,6 +42,13 @@ c                HeightList has priority
        if(NoOfSites .eq. 0) then
           call cerrorMsg('No of Observation sites = 0', 0)
        endif
+c        set polar angle of the injection pointsite.
+c        (used when ObsPlane==spherical)
+       call csetCoord('llh', LatitOfSite, LongitOfSite, 
+     *    HeightOfInj,   PolarInjPos)
+c        transform it to polar coord.
+       call ctransCoord2('sph', PolarInjPos, PolarInjPos)
+
        if(EndLevel .eq. 0) EndLevel = NoOfSites   ! 96.09.18
 c               set magnetic field for the deepest level. 
 c                 Magfield is 'ned' here
@@ -122,6 +129,11 @@ c        check if in the ascending order of detph
        if(error) then
           call cerrorMsg('Obsev. depth/height not in order', 0)
        endif
+       if(ObsPlane .eq. spherical .and. Za1ry .ne. 'is') then
+          call cerrorMsg(
+     *      "ObsPlane==spherical but Za1ry !='is'",0)
+       endif
+
 c         +++++++++++++++++++++++ for AS ++++++++++++++++
        NoOfASSites = 0
        do i = 1, maxNoOfASSites
